
/* 
Une mutation pour rajouter dans la BDD les types SimpleGroup et MetaGroup 
(cf la documentation de l'interface GraphQL)
Les objets qui étaient jusqu''à présent stoqués dans la table groups 
sont déplacés dans la table simple_groups
En cas de rollback, le déplacement se fait dans l'autre sens
(et les meta groupes sont perdus)

Après cette mutation, plus rien n'est sensé être mis directement dans la table groups
*/

exports.up = function(knex, Promise) {
    return knex('groups').select().then( groups_content => {
        return knex('groups').del().then(function () {
            return knex.schema.table('groups', function (table){
                table.dropColumn('school');
                table.dropColumn('parentuid');
            }).then(()=> {
                return knex.schema.createTable('simple_groups', function (table){
                    table.inherits('groups');
                    table.string('parentuid');
                    table.enum('school', ['polytechnique', 'ensta', 'supoptique']).notNullable();
                }).then(() => {
                    return knex.schema.createTable('meta_groups', function (table){
                        table.inherits('groups');
                    }).then(function(){
                        return knex('simple_groups').insert(groups_content);
                    });
                });
            });
        });
    });
};

exports.down = function(knex, Promise) {
    return knex('simple_groups').select().then(simple_groups_content => {
        return knex.schema.dropTable('simple_groups').then(function (){
            return knex.schema.dropTable('meta_groups').then(function (){
                return knex.schema.table('groups', function (table){
                    table.string('parentuid');
                    table.enum('school', ['polytechnique', 'ensta', 'supoptique']).notNullable();
                }).then(function (){
                    return knex('groups').insert(simple_groups_content);
                });
            });
        });
    });
};
